Index: tools/testing/dart/multitest.dart |
diff --git a/tools/testing/dart/multitest.dart b/tools/testing/dart/multitest.dart |
index 5170ac1f46a5fe553e78033548179ce4f1c67de5..4e1b71665163fd867693d6f6ef7bea150664b3f2 100644 |
--- a/tools/testing/dart/multitest.dart |
+++ b/tools/testing/dart/multitest.dart |
@@ -160,9 +160,9 @@ Set<String> _findAllRelativeImports(String topLibrary) { |
String libraryDir = topLibrary.substring(0, end); |
// Matches #import( or #source( followed by " or ' followed by anything |
- // except dart: or /, at the beginning of a line. |
- RegExp relativeImportRegExp = |
- const RegExp('^#(import|source)[(]["\'](?!(dart:|/))([^"\']*)["\']'); |
+ // except dart:, dart-ext: or /, at the beginning of a line. |
+ RegExp relativeImportRegExp = const RegExp( |
+ '^#(import|source)[(]["\'](?!(dart:|dart-ext:|/))([^"\']*)["\']'); |
while (!toSearch.isEmpty()) { |
var thisPass = toSearch; |
toSearch = new HashSet<String>(); |